@@ -1,6 +1,6 @@
 package Alvis::TermTagger;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 #######################################################################
 #
@@ -176,9 +176,30 @@ sub get_Regex_TermList {
 #	warn $ref_regex_lemmaWordtermlist->[$term_counter] . "\n";
  	$ref_regex_termlist->[$term_counter] =~ s/([()\',\[\]\?\!:;\/.\+\-\*\#\{\}\\])/\\$1/og;
 	$ref_regex_termlist->[$term_counter] =~ s/ /[\- \n]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/A/[\x{00C0}-\x{00C5}\x{00E0}-\x{00E5}A]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/AE/(\x{00C6}|AE)/og;
+	$ref_regex_termlist->[$term_counter] =~ s/C/[\x{00C7}|C]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/E/[\x{00C8}-\x{00CB}E]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/I/[\x{00CC}-\x{00CF}I]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/D/[\x{00D0}D]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/N/[\x{00D1}N]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/O/[\x{00D2}-\x{00D8}O]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/U/[\x{00D9}-\x{00DC}U]/og;
+	$ref_regex_termlist->[$term_counter] =~ s/Y/[\x{00DD}Y]/og;
+
 	if (defined $ref_regex_lemmaWordtermlist) {
 	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/([()\',\[\]\?\!:;\/.\+\-\*\#\{\}\\])/\\$1/og;
 	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/ /[\- \n]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/A/[\x{00C0}-\x{00C5}A]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/AE/(\x{00C6}|AE)/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/C/[\x{00C7}C]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/E/[\x{00C8}-\x{00CB}E]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/I/[\x{00CC}-\x{00CF}I]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/D/[\x{00D0}D]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/N/[\x{00D1}N]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/O/[\x{00D2}-\x{00D8}O]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/U/[\x{00D9}-\x{00DC}U]/og;
+	    $ref_regex_lemmaWordtermlist->[$term_counter] =~ s/Y/[\x{00DD}Y]/og;
 	}
     }
     print STDERR "\n\tTerm/regex list size : " . scalar(@$ref_regex_termlist);
@@ -240,6 +261,17 @@ sub corpus_Indexing {
 		$word = $tab_words_lc[$i];
 	    }
 	    if ($word ne "") {
+		$word =~ s/[\x{00C0}-\x{00C5}\x{00E0}-\x{00E5}]/A/og;
+		$word =~ s/\x{00C6}/AE/og;
+		$word =~ s/[\x{00C7}]/C/og;
+		$word =~ s/[\x{00C8}-\x{00CB}]/E/og;
+		$word =~ s/[\x{00CC}-\x{00CF}]/I/og;
+		$word =~ s/[\x{00D0}]/D/og;
+		$word =~ s/[\x{00D1}]/N/og;
+		$word =~ s/[\x{00D2}-\x{00D8}]/O/og;
+		$word =~ s/[\x{00D9}-\x{00DC}]/U/og;
+		$word =~ s/[\x{00DD}]/Y/og;
+
 		if (!exists $ref_corpus_index->{$word}) {
 		    my @tabtmp;
 		    $ref_corpus_index->{$word} = \@tabtmp;
@@ -590,28 +622,28 @@ sub term_tagging_offset_brat {
 		(((!defined $caseSensitive) || ($caseSensitive < 0) || (length($ref_termlist->[$counter]->[$termField2]) > $caseSensitive)) && 
 		 ($line =~ /(?<before>[,.?!:;\/ \n\-\/\*'\#\{\}\(\)\[\]\+])(?<term>$term_regex)[,.?!:;\/ \n\-\/\*'\#\(\)\[\]\{\}\+]/is))) {
 		$currOffset = $offset+length($`)+length($+{before});
- 		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset + length($+{term}));
+ 		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset + length($+{term}),$ref_termlist->[$counter]->[2]);
 	    }
  	    if ((((defined $caseSensitive) && (($caseSensitive == 0) || (length($ref_termlist->[$counter]->[$termField2]) <= $caseSensitive))) &&
 		 ($line =~ /^(?<term>$term_regex)[,.?!:;\/ \n\-\/\*'\#\(\)\[\]\{\}\+]/s)) ||
 		(((!defined $caseSensitive) || ($caseSensitive < 0) || (length($ref_termlist->[$counter]->[$termField2]) > $caseSensitive)) && 
 		 ($line =~ /^(?<term>$term_regex)[,.?!:;\/ \n\-\/\*'\#\(\)\[\]\{\}\+]/is))) {
 		$currOffset = $offset+length($`);
-		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset + length($+{term}));
+		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset + length($+{term}),$ref_termlist->[$counter]->[2]);
 	    }
 	    if ((((defined $caseSensitive) && (($caseSensitive == 0) || (length($ref_termlist->[$counter]->[$termField2]) <= $caseSensitive))) &&
 		 ($line =~ /(?<before>[,.?!:;\/ \n\-\/\*'\#\(\)\[\]\{\}\+])(?<term>$term_regex)$/s)) ||
 		(((!defined $caseSensitive) || ($caseSensitive < 0) || (length($ref_termlist->[$counter]->[$termField2]) > $caseSensitive)) && 
 		 ($line =~ /(?<before>[,.?!:;\/ \n\-\/\*'\#\(\)\[\]\{\}\+])(?<term>$term_regex)$/is))) {
 		$currOffset = $offset+length($`)+length($+{before});
-		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset+length($+{term}));
+		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset+length($+{term}),$ref_termlist->[$counter]->[2]);
 	    }
  	    if ((((defined $caseSensitive) && (($caseSensitive == 0) || (length($ref_termlist->[$counter]->[$termField2]) <= $caseSensitive))) &&
 		 ($line =~ /^(?<term>$term_regex)$/s)) ||
 		(((!defined $caseSensitive) || ($caseSensitive < 0) || (length($ref_termlist->[$counter]->[$termField2]) > $caseSensitive)) && 
 		 ($line =~ /^(?<term>$term_regex)$/is))) {
 		$currOffset = $offset+length($`);
-		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset+length($+{term}));
+		print_brat_output(\*TAGGEDCORPUS, \$termId, $+{term}, $currOffset, $currOffset+length($+{term}),$ref_termlist->[$counter]->[2]);
 	    }
 	}
 	$i++;
@@ -624,9 +656,13 @@ sub term_tagging_offset_brat {
 }
 
 sub print_brat_output() {
-    my ($descriptor, $termId, $matching_term, $start_offset, $end_offset) = @_;
+    my ($descriptor, $termId, $matching_term, $start_offset, $end_offset, $semtag) = @_;
 
-    print $descriptor "T$$termId\tterm $start_offset $end_offset\t$matching_term\n";
+    if ((!defined $semtag) || ($semtag =~ /^\s*$/)) {
+	$semtag = "term";
+    }
+
+    print $descriptor "T$$termId\t$semtag $start_offset $end_offset\t$matching_term\n";
     $$termId++;
 }
 
@@ -653,8 +689,8 @@ sub printMatchingTerm_tab() {
 	    $tmp_key .= $term;
 
 	    push @tab_tmp, $sent_id;
-	    push @tab_tmp, @$ref_matching_term;
 	    push @tab_tmp, $term;
+	    push @tab_tmp, @$ref_matching_term;
 
 	    # warn "term_key: $tmp_key\n";
 	    # if (!exists $ref_tab_results->{$tmp_key}) {
@@ -664,10 +700,10 @@ sub printMatchingTerm_tab() {
 	    } else {
 		# warn "exists\n";
 #		push @{$ref_tab_results->{$tmp_key}}, @tab_tmp;
-		if (defined $tab_tmp[3]) {
-		    $ref_tab_results->{$tmp_key}->[3] .= ";" . $tab_tmp[3];
+		if (defined $tab_tmp[4]) {
+		    $ref_tab_results->{$tmp_key}->[4] .= ";" . $tab_tmp[4];
 		} else {
-		    $ref_tab_results->{$tmp_key}->[3] .= ";";
+		    $ref_tab_results->{$tmp_key}->[4] .= ";";
 		}
 	    }
 	    # warn "tab_tmp: " . join ("\t", @{$ref_tab_results->{$tmp_key}}) . "\n";
@@ -681,6 +717,7 @@ sub printMatchingTerm_tab() {
     }
 }
 
+
 1;
 
 __END__
@@ -907,7 +944,7 @@ separated by a tabulation character.
     print_brat_output($descriptor, $termId, $matching_term, $start_offset, $end_offset);
 
 This method prints into the file descriptor C<$descriptor>, the term
-id (C<$termId>), the start and end offset of the term
+id (C<$termId>), its semantic tag, the start and end offset of the term
 (C<$start_offset> and C<$end_offset>) and the matching term (named by
 its reference C<$matching_term>) in the Brat input. Both data are on a
 line and are separated by a tabulation character.
